@@ -26,6 +26,7 @@ use crate::arithmetic::SqrtTables;
 // integers in little-endian order. `Fp` values are always in
 // Montgomery form; i.e., Fp(a) = aR mod p, with R = 2^256.
 #[derive(Clone, Copy, Eq)]
+#[repr(transparent)]
 pub struct Fp(pub(crate) [u64; 4]);
 
 impl fmt::Debug for Fp {
@@ -770,6 +771,21 @@ impl FieldExt for Fp {
     }
 }
 
+#[cfg(feature = "gpu")]
+impl ec_gpu::GpuField for Fp {
+    fn one() -> alloc::vec::Vec<u32> {
+        crate::fields::u64_to_u32(&R.0[..])
+    }
+
+    fn r2() -> alloc::vec::Vec<u32> {
+        crate::fields::u64_to_u32(&R2.0[..])
+    }
+
+    fn modulus() -> alloc::vec::Vec<u32> {
+        crate::fields::u64_to_u32(&MODULUS.0[..])
+    }
+}
+
 #[cfg(test)]
 use ff::Field;
 
