@@ -26,6 +26,7 @@ use crate::arithmetic::SqrtTables;
 // integers in little-endian order. `Fq` values are always in
 // Montgomery form; i.e., Fq(a) = aR mod q, with R = 2^256.
 #[derive(Clone, Copy, Eq)]
+#[repr(transparent)]
 pub struct Fq(pub(crate) [u64; 4]);
 
 impl fmt::Debug for Fq {
@@ -769,6 +770,21 @@ impl FieldExt for Fq {
     }
 }
 
+#[cfg(feature = "gpu")]
+impl ec_gpu::GpuField for Fq {
+    fn one() -> alloc::vec::Vec<u32> {
+        crate::fields::u64_to_u32(&R.0[..])
+    }
+
+    fn r2() -> alloc::vec::Vec<u32> {
+        crate::fields::u64_to_u32(&R2.0[..])
+    }
+
+    fn modulus() -> alloc::vec::Vec<u32> {
+        crate::fields::u64_to_u32(&MODULUS.0[..])
+    }
+}
+
 #[cfg(test)]
 use ff::Field;
 
